@@ -8,6 +8,7 @@ use std::error::Error;
 use std::fmt;
 use std::str::FromStr;
 
+#[non_exhaustive]
 #[derive(Clone, Debug, Eq, PartialEq)]
 pub struct OptionPosition {
     /// The symbol of the option itself.
@@ -33,6 +34,12 @@ pub struct OptionPosition {
     /// The delta per contract in this position.
     pub unit_delta: Option<NotNan<f64>>,
 
+    /// The vega per contract in this position.
+    pub unit_vega: Option<NotNan<f64>>,
+
+    /// The theta per contract in this position.
+    pub unit_theta: Option<NotNan<f64>>,
+
     /// The number of contracts in this position.
     pub quantity: usize,
 
@@ -92,6 +99,14 @@ impl OptionPosition {
         self.unit_delta.map(|x| x * self.quantity as f64)
     }
 
+    pub fn vega(&self) -> Option<NotNan<f64>> {
+        self.unit_vega.map(|x| x * self.quantity as f64)
+    }
+
+    pub fn theta(&self) -> Option<NotNan<f64>> {
+        self.unit_theta.map(|x| x * self.quantity as f64)
+    }
+
     pub fn profit_at_expiry(&self, underlying_price: Rational64) -> Rational64 {
         let lot_size: i64 = self.lot_size.unwrap_or(100).try_into().unwrap();
 
@@ -120,6 +135,8 @@ impl OptionPosition {
             unit_bid_price: None,
             unit_ask_price: None,
             unit_delta: None,
+            unit_vega: None,
+            unit_theta: None,
             quantity,
             lot_size: None,
         }
@@ -232,6 +249,7 @@ impl Default for OptionType {
     }
 }
 
+#[non_exhaustive]
 #[derive(Clone, Debug, Eq, PartialEq)]
 pub struct StrategyBreakevens {
     // breakevens sorted with ascending price
@@ -266,6 +284,7 @@ impl StrategyBreakevens {
     }
 }
 
+#[non_exhaustive]
 #[derive(Clone, Debug, Eq, PartialEq)]
 pub struct Breakeven {
     pub price: Rational64,
@@ -333,6 +352,7 @@ pub fn calculate_breakevens_for_strategy(options: &[OptionPosition]) -> Strategy
     StrategyBreakevens { breakevens }
 }
 
+#[non_exhaustive]
 #[derive(Clone, Debug, Eq, PartialEq)]
 pub struct StrategyProfitBounds {
     pub max_loss: Option<ProfitBound>,
@@ -906,7 +926,7 @@ mod tests {
 
         fn expiration_date() -> ExpirationDate {
             ExpirationDate(NaiveDate::from_ymd(2020, 10, 16))
-        };
+        }
 
         struct IVProvider;
         impl ExpirationImpliedVolatilityProvider for IVProvider {
